RenderError

Enum RenderError 

pub enum RenderError {
    InvalidModuleSource {
        width: usize,
        height: usize,
        len: usize,
    },
    ModuleSourceTooWide {
        width: usize,
    },
    OutputTooLarge,
}
Errors returned by fallible render construction or rendering.

Variants



InvalidModuleSource

The module source is not a non-empty square row-major QR module grid.

Fields

width: usize

Source width in modules.

height: usize

Source height in modules.

len: usize

Number of row-major modules exposed by the source.



ModuleSourceTooWide

The module source is wider than this renderer can represent internally.

Fields

width: usize

Source width in modules.



OutputTooLarge

The requested quiet zone, module size, or final canvas dimensions overflow this renderer’s coordinate space or exceed the backend’s buffer and output budget.