pub trait Element: Copy {
// Required methods
fn default_color(color: Color) -> Self;
fn strlen(self) -> usize;
fn append_to_string(self, string: &mut String);
}Expand description
A renderable character or string fragment used by the plain-text renderer.
Implemented for char and &'static str so a Renderer
can be driven with either.
Required Methods
Sourcefn default_color(color: Color) -> Self
fn default_color(color: Color) -> Self
Returns the default element for a dark or light module.
Sourcefn append_to_string(self, string: &mut String)
fn append_to_string(self, string: &mut String)
Appends this element to string.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".